==> 0.0.1%2B1.tar.gz: lib/models/IR5PointageReq.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Delivry.dart" show IR5Delivry;
import "IR5Member.dart" show IR5Member;
import "IR5PointageConso.dart" show IR5PointageConso;
import "IR5PointagePay.dart" show IR5PointagePay;

part 'IR5PointageReq.g.dart';

// --------------------------------------------------------------------------------
@JsonSerializable(explicitToJson: true)
class IR5PointageReq {
  IR5PointageReq({
    required this.NoTbl,
    required this.SsTbl,
    this.Nom,
    this.TblType,
    this.Cvts,
    this.TblMode,
    this.TblIsEmport,
    this.TblDivision,
    this.Action,
    this.TicketProd,
    this.AddBlanco,
    this.DetailsFmt,
    this.Notify,
    this.MemberCard,
    this.MemberBarcode,
    this.Member,
    required this.Delivry,
    this.Tariff,
    this.Consos,
    this.Pays,
  });

  factory IR5PointageReq.fromJson(Map<String, dynamic>? json) => _$IR5PointageReqFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PointageReqToJson(this);

  /** Accept also Tbl:Xxx.x */
  @JsonKey(defaultValue: '')
  final String NoTbl;
  @JsonKey(defaultValue: '')
  final String SsTbl;

  /** Free Table Name. ex: nom + prénom + gsm du client */
  final String? Nom;

  /** TblType: 11 - Normal | 12 - Comptoir | 13 - V.Tbl Bar | 14 - Personnel | 15 - Traiteur | 16 - Taverne | 17 - Delivery | 18 - Pickup | 19 - Auto Inc | 20 - Type J | 91 - SplitAPart | 92 - EnCaisse */
  final num? TblType;
  final num? Cvts;

  /** TblMode: 0:ReadOnly | 1:ReadWrite| 2:TrainingReadOnly | 3:TrainingReadWrite */
  final num? TblMode;
  final bool? TblIsEmport;
  final num? TblDivision;

  /** Action to perform: Lancer|Addition|Cloture|... or Refused or HistoAction Enum */
  final String? /* String | HistoAction */ Action;

  /** Do Print Ticket(s) Prod */
  final bool? TicketProd;

  /** Do Print Add (if not present will follow Restomax Rules) */
  final bool? AddBlanco;

  /** Response DetailsFmt: Details | Addition | AddBySsAdd | AddBySeq. */
  final String? DetailsFmt;

  /** Who to Notify when Restomax will cloture the Tbl (Should be configured in Restomax.Etab.ProdCtrl ini section notify) */
  final String? Notify;

  /** Member NumCard. numéro identifiant le membre (alphanum) */
  final String? MemberCard;

  /** Member Barcode. Barcode identifiant le membre (alphanum) */
  final String? MemberBarcode;
  final IR5Member? Member;

  /** Delivry Or Take Away Info. */
  final IR5Delivry Delivry;

  /** Tariff used / to use */
  final num? Tariff;
  final List<IR5PointageConso>? Consos;
  final List<IR5PointagePay>? Pays;
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5PointageReq.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5Delivry.dart" show IR5Delivry;
import "IR5Member.dart" show IR5Member;
import "IR5PointageConso.dart" show IR5PointageConso;
import "IR5PointagePay.dart" show IR5PointagePay;

part 'IR5PointageReq.g.dart';

// --------------------------------------------------------------------------------
@JsonSerializable(explicitToJson: true)
class IR5PointageReq {
  IR5PointageReq({
    required this.NoTbl,
    required this.SsTbl,
    this.Nom,
    this.TblType,
    this.Cvts,
    this.TblMode,
    this.TblIsEmport,
    this.TblDivision,
    this.Action,
    this.TicketProd,
    this.AddBlanco,
    this.DetailsFmt,
    this.Notify,
    this.MemberCard,
    this.MemberBarcode,
    this.Member,
    required this.Delivry,
    this.Tariff,
    this.Consos,
    this.Pays,
  });

  factory IR5PointageReq.fromJson(Map<String, dynamic>? json) =>
      _$IR5PointageReqFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5PointageReqToJson(this);

  /** Accept also Tbl:Xxx.x */
  @JsonKey(defaultValue: '')
  final String NoTbl;
  @JsonKey(defaultValue: '')
  final String SsTbl;

  /** Free Table Name. ex: nom + prénom + gsm du client */
  final String? Nom;

  /** TblType: 11 - Normal | 12 - Comptoir | 13 - V.Tbl Bar | 14 - Personnel | 15 - Traiteur | 16 - Taverne | 17 - Delivery | 18 - Pickup | 19 - Auto Inc | 20 - Type J | 91 - SplitAPart | 92 - EnCaisse */
  final num? TblType;
  final num? Cvts;

  /** TblMode: 0:ReadOnly | 1:ReadWrite| 2:TrainingReadOnly | 3:TrainingReadWrite */
  final num? TblMode;
  final bool? TblIsEmport;
  final num? TblDivision;

  /** Action to perform: Lancer|Addition|Cloture|... or Refused or HistoAction Enum */
  final String? /* String | HistoAction */ Action;

  /** Do Print Ticket(s) Prod */
  final bool? TicketProd;

  /** Do Print Add (if not present will follow Restomax Rules) */
  final bool? AddBlanco;

  /** Response DetailsFmt: Details | Addition | AddBySsAdd | AddBySeq. */
  final String? DetailsFmt;

  /** Who to Notify when Restomax will cloture the Tbl (Should be configured in Restomax.Etab.ProdCtrl ini section notify) */
  final String? Notify;

  /** Member NumCard. numéro identifiant le membre (alphanum) */
  final String? MemberCard;

  /** Member Barcode. Barcode identifiant le membre (alphanum) */
  final String? MemberBarcode;
  final IR5Member? Member;

  /** Delivry Or Take Away Info. */
  final IR5Delivry Delivry;

  /** Tariff used / to use */
  final num? Tariff;
  final List<IR5PointageConso>? Consos;
  final List<IR5PointagePay>? Pays;
}
